@@ -174,59 +174,3 @@ class LoggerCallback(Callback):
         col_ids = [2, 4+len(self.metrics)]
         z = self.df.iloc[:,col_ids].values
         plot(*list(zip(*z))); plt.show(); time.sleep(.01)
-
-
-class Runner:
-    def __init__(self, path, data, get_learner, nruns=10, eps=10, name='Runner', desc='', load=False):
-        self.get_learner, self.data = get_learner, data
-        self.nruns, self.eps, self.name, self.desc = nruns, eps, name, desc
-        if not Path(f'{path}/runners').exists(): Path(f'{path}/runners').mkdir()
-        self.fname = f'{path}/runners/{name}'
-        self.learner, self.df, self.best = None, None, 0.
-        if load: self.load()
-
-    def __call__(self, mute=True):
-        self.best, self.best_file = 0., None
-        if mute: disablePrint()
-        for i in range(self.nruns):
-            force_print(f'\rRun {i}')
-            learner = self.get_learner(self.data, name= f'{self.name}_{i}', plot=False)
-            self.learner = learner
-            learner.fit(self.eps)
-            learner.load(mute=True)
-            df1 = learner.logger.df_best
-            df1['Best'] = ''
-            self.df = df1.copy() if self.df is None else pd.concat((self.df,df1),ignore_index=True)
-            if learner.logger.best > self.best:
-                self.best, self.best_file = learner.logger.best, f'{self.name}_{i}'
-                print(f'New best: {self.best:.4f}')
-                display(self.df.iloc[[-1]])
-            self.df['Best'] = ''
-            self.df.loc[self.df.iloc[:,key_metric(learner)]==self.best, 'Best'] = '*'
-            self.save()
-            learner.close()
-            del learner
-            gc.collect()
-        self.save()
-        print(f'\nBest file: {self.best_file}')
-        display(self.df)
-        enablePrint()
-
-    def save(self):
-        meta = {'desc': self.desc, 'best': self.best, 'best_file': self.best_file}
-        pickle.dump(meta, open(self.fname+'.pickle', 'wb'))
-        self.df.to_csv(self.fname+'.csv', index=False)
-
-    def load(self):
-        p_pickle, p_csv = Path(f'{self.fname}.pickle'), Path(f'{self.fname}.csv')
-        if not p_pickle.exists() or not p_csv.exists(): return
-        meta = pickle.load(open(self.fname+'.pickle', 'rb'))
-        if not 'cols' in meta or not 'best' in meta or not 'best_file' in meta: return
-        print(f'Loaded from file {self.fname}: {meta}')
-        self.desc, self.best, self.best_file = meta['desc'], meta['best'], meta['best_file']
-        self.df = pd.read_csv(self.fname+'.csv')
-        self.df['Best'] = self.df['Best'].fillna('')
-
-    def df_best(self):
-        if self.learner is None: return None
-        return self.df[self.df.iloc[:,key_metric(self.learner)]==self.best].iloc[[0]]
